/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if USE(LIBWEBRTC)
#include "LibWebRTCNetwork.h"

#include "DataReference.h"
#include "Decoder.h"
#include "HandleMessage.h"
#include "LibWebRTCNetworkMessages.h"
#include "RTCNetwork.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/LibWebRTCSocketIdentifier.h>

namespace WebKit {

void LibWebRTCNetwork::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::LibWebRTCNetwork::SignalReadPacket::name()) {
        IPC::handleMessage<Messages::LibWebRTCNetwork::SignalReadPacket>(decoder, this, &LibWebRTCNetwork::signalReadPacket);
        return;
    }
    if (decoder.messageName() == Messages::LibWebRTCNetwork::SignalSentPacket::name()) {
        IPC::handleMessage<Messages::LibWebRTCNetwork::SignalSentPacket>(decoder, this, &LibWebRTCNetwork::signalSentPacket);
        return;
    }
    if (decoder.messageName() == Messages::LibWebRTCNetwork::SignalAddressReady::name()) {
        IPC::handleMessage<Messages::LibWebRTCNetwork::SignalAddressReady>(decoder, this, &LibWebRTCNetwork::signalAddressReady);
        return;
    }
    if (decoder.messageName() == Messages::LibWebRTCNetwork::SignalConnect::name()) {
        IPC::handleMessage<Messages::LibWebRTCNetwork::SignalConnect>(decoder, this, &LibWebRTCNetwork::signalConnect);
        return;
    }
    if (decoder.messageName() == Messages::LibWebRTCNetwork::SignalClose::name()) {
        IPC::handleMessage<Messages::LibWebRTCNetwork::SignalClose>(decoder, this, &LibWebRTCNetwork::signalClose);
        return;
    }
    if (decoder.messageName() == Messages::LibWebRTCNetwork::SignalNewConnection::name()) {
        IPC::handleMessage<Messages::LibWebRTCNetwork::SignalNewConnection>(decoder, this, &LibWebRTCNetwork::signalNewConnection);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // USE(LIBWEBRTC)
