/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "RemoteSampleBufferDisplayLayerManager.h"

#include "ArgumentCoders.h"
#include "Decoder.h"
#include "HandleMessage.h"
#include "LayerHostingContext.h"
#include "RemoteSampleBufferDisplayLayerManagerMessages.h"
#include "SampleBufferDisplayLayerIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/IntSize.h>
#include <wtf/Optional.h>

namespace Messages {

namespace RemoteSampleBufferDisplayLayerManager {

void CreateLayer::callReply(IPC::Decoder& decoder, CompletionHandler<void(Optional<WebKit::LayerHostingContextID>&&)>&& completionHandler)
{
    Optional<Optional<WebKit::LayerHostingContextID>> contextID;
    decoder >> contextID;
    if (!contextID) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*contextID));
}

void CreateLayer::cancelReply(CompletionHandler<void(Optional<WebKit::LayerHostingContextID>&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<Optional<WebKit::LayerHostingContextID>>::create());
}

void CreateLayer::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Optional<WebKit::LayerHostingContextID>& contextID)
{
    *encoder << contextID;
    connection.sendSyncReply(WTFMove(encoder));
}

} // namespace RemoteSampleBufferDisplayLayerManager

} // namespace Messages

namespace WebKit {

void RemoteSampleBufferDisplayLayerManager::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    auto protectedThis = makeRef(*this);
    if (decoder.messageName() == Messages::RemoteSampleBufferDisplayLayerManager::CreateLayer::name()) {
        IPC::handleMessageAsync<Messages::RemoteSampleBufferDisplayLayerManager::CreateLayer>(connection, decoder, this, &RemoteSampleBufferDisplayLayerManager::createLayer);
        return;
    }
    if (decoder.messageName() == Messages::RemoteSampleBufferDisplayLayerManager::ReleaseLayer::name()) {
        IPC::handleMessage<Messages::RemoteSampleBufferDisplayLayerManager::ReleaseLayer>(decoder, this, &RemoteSampleBufferDisplayLayerManager::releaseLayer);
        return;
    }
    if (dispatchMessage(connection, decoder))
        return;
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
